# -*- coding: utf-8; tab-width: 4; indent-tabs-mode: nil -*-
#
# Copyright (C) 2009 - Jeremy AustinBardo <ausimage@ubuntu.com>
# Copyright (C) 2006 - Florian Ludwig <dino@phidev.info>,
#   Franz Pletz <fpletz@franz-pletz.org>
#
# Apt-zeroconf is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Apt-zeroconf is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with apt-zeroconf; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""
Utility Methods Module for apt-zeroconf

@requires: re
@requires: avahi.PROTO_INET6
"""
import re

def synchronized(lock):
    """
    Synchronized threading lock decorator.

    @param lock: threading.lock()
    @type lock: object
    """
    def wrap(f):
        def func(*args, **kw):
            lock.acquire()
            try:
                return f(*args, **kw)
            finally:
                lock.release()
        return func
    return wrap


EPOCH_PATTERN = re.compile(r'\_\d+\%3a')

def prune_epoch(f):
    """
    Prune Epoch from package.

    @param f: package name
    @type f: basestring
    """
    return EPOCH_PATTERN.sub('_', f)

def make_url(address, port, proto):
    """
    Build url with address and port. Only bracket adress, if proto is
    avahi.PROTO_INET6.

    @param address: server address
    @type address: basestring
    @param port: server port
    @type port: int
    @param proto: avahi.PROTO_* value
    @type proto: int
    @requires: avahi.PROTO_INET6
    """
    from avahi import PROTO_INET6
    return '%s:%i' % \
        ((proto == PROTO_INET6 and '[%s]' or '%s') % address, port)

