#!/bin/bash
##########   FoKoN 9.10   ###########\
# Intégration de poste Ubuntu 9.04   #
# dans un domaine Active Directory   #
# géré par IACA.                     #
#------------------------------------#
# Script : reseau.sh                 #
# Changement du nom de poste.        #
# Connexion au réseau local et à     #
# Internet (DNS, Proxies, etc.)      #
# Synchro horaire.                   #
#------------------------------------#
# Auteur : Claude CLERC              #
# <claude.clerc@ac-aix-marseille.fr> #
# Site : http://www.fokon.org        #
# Licence : CeCILL - GPL 2.0         #
#####################################/

FOKONDIR=`dirname $0`	# Dossier de ce script.
# On intègre les vérifications d'usage:
. ${FOKONDIR}/common.sh

[ -f ${FOKONDIR}/variables ] || { 
	exit 1
}

. ${FOKONDIR}/variables

TEMPLATES=${FOKONDIR}/templates

### Changement du nom de poste
liste_f="etc/hostname etc/hosts"
transforme
hostname ${NOMPOSTE}
echo "Le nom du poste est dorénavant : ${NOMPOSTE}"

### Modif de /etc/nsswitch.conf, si le nom de domaine finit par .local
[ "${DOMAINE_NOM_DNS:-6}" = ".local" ] && NSSWITCH_HOSTS="files dns mdns4_minimal [NOTFOUND=return] mdns4"
[ "${DOMAINE_NOM_DNS:-6}" = ".local" ] || NSSWITCH_HOSTS="files mdns4_minimal [NOTFOUND=return] dns mdns4"
NSSWITCH_HOSTS="files dns mdns4_minimal [NOTFOUND=return] mdns4"
export NSSWITCH_HOSTS
liste_f="etc/nsswitch.conf"
transforme

### Vérifications du fonctionnement du DNS
DNS_OK=0
LEN_NOM=${#SRVIACA_NOM} # longueur du nom du serveur IACA
REPONSE_NS=`host ${SRVIACA_NOM}`
[ "${REPONSE_NS:0:${LEN_NOM}}" = "${SRVIACA_NOM}" ] && DNS_OK=1 # le nom de IACA est-il résolu ?
# Sinon, on essaye d'indiquer le bon DNS
[ $DNS_OK -eq 0 ] && {
	NS_LOCAL=`cat /etc/resolv.conf | grep nameserver | awk '{print $2}'`
	[ "${NS_LOCAL}" = "${DNS_IP}" ] || {
		liste_f="etc/resolv.conf"
		transforme
	}
}
# et on recommence le même test
REPONSE_NS=`host ${SRVIACA_NOM}`
[ "${REPONSE_NS:0:${LEN_NOM}}" = "${SRVIACA_NOM}" ] && DNS_OK=1 # le nom de IACA est-il résolu ?
[ $DNS_OK -eq 0 ] && {
	[ "${REPONSE_NS:-10:10}" = "(SERVFAIL)" ] && echo "Votre serveur DNS ${DNS_IP} ne sait pas résoudre le nom ${SRVIACA_NOM} !"
	[ "${REPONSE_NS:0:2}" = ";;" ] && echo "Votre serveur DNS ${DNS_IP} n'est pas accessible !"
	exit 1
}
echo "Votre serveur DNS ${DNS_IP} a l'air de fonctionner correctement."

### Synchronisation horaire avec le serveur IACA
liste_f="etc/default/ntpdate"
transforme
echo "Mise à l'heure à partir du serveur IACA : "
ntpdate-debian

### Configuration du Proxy (ou des Proxies)
[ "${PROXY_NB}" = "0" ] && {
	liste_f="etc/apt/apt.conf etc/environment /etc/wgetrc"
	ORIG_RESTORED=""
	for f in liste_f ; do {
		[ -f ${DIR_SVG}/${RACINE}/${f}_ORIG ] && {
			[ -f ${RACINE}/${f} ] && {
				rm ${RACINE}/${f}
				cp -a ${DIR_SVG}/${RACINE}/${f}_ORIG ${RACINE}/${f}
				ORIG_RESTORED=" Les fichiers originaux de configuration de proxies ont été restaurés."
			}
		}
	}; done
	export http_proxy=""
	echo "Aucune configuration de Serveur mandataire (proxy) n'est requise.${ORIG_RESTORED}"
}
[ "${PROXY_NB}" = "0" ] || {
	touch ${RACINE}/root/.wgetrc
	touch ${RACINE}/etc/skel/.wgetrc
	liste_f="etc/apt/apt.conf etc/environment etc/wgetrc etc/skel/.wgetrc root/.wgetrc"
	transforme

	chmod 640 ${RACINE}/etc/apt/apt.conf
	chown root:admin ${RACINE}/etc/apt/apt.conf

	rm -f ${RACINE}/${HOME}/.wgetrc
	cp ${RACINE}/root/.wgetrc ${RACINE}/${HOME}/.wgetrc
	chown ${HOME:6}:${HOME:6} ${RACINE}/${HOME}/.wgetrc
	chmod 640 ${RACINE}/${HOME}/.wgetrc
	export http_proxy="${STR_PROXY_SYS}"
	echo "Proxy configuré."
}

#./test.pl

#[ "${RACINE}" = ""  ] || {
#	[ "${RACINE}" = "/"  ] || chown -R administrateur:administrateur ${RACINE}/
#}
